/****************************************************************************
** Meta object code from reading C++ file 'knotification.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../knotifications-6.29.0/src/knotification.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'knotification.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KNotificationActionE_t {};
} // unnamed namespace

template <> constexpr inline auto KNotificationAction::qt_create_metaobjectdata<qt_meta_tag_ZN19KNotificationActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KNotificationAction",
        "activated",
        "",
        "labelChanged",
        "label"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'label'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KNotificationAction, qt_meta_tag_ZN19KNotificationActionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KNotificationAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KNotificationActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KNotificationActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KNotificationActionE_t>.metaTypes,
    nullptr
} };

void KNotificationAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KNotificationAction *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activated(); break;
        case 1: _t->labelChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KNotificationAction::*)()>(_a, &KNotificationAction::activated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotificationAction::*)(const QString & )>(_a, &KNotificationAction::labelChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KNotificationAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNotificationAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KNotificationActionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNotificationAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KNotificationAction::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KNotificationAction::labelChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN13KNotificationE_t {};
} // unnamed namespace

template <> constexpr inline auto KNotification::qt_create_metaobjectdata<qt_meta_tag_ZN13KNotificationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KNotification",
        "closed",
        "",
        "ignored",
        "eventIdChanged",
        "titleChanged",
        "textChanged",
        "iconNameChanged",
        "defaultActionChanged",
        "actionsChanged",
        "flagsChanged",
        "componentNameChanged",
        "urlsChanged",
        "urgencyChanged",
        "autoDeleteChanged",
        "xdgActivationTokenChanged",
        "hintsChanged",
        "close",
        "sendEvent",
        "setHint",
        "hint",
        "QVariant",
        "value",
        "hints",
        "QVariantMap",
        "setHints",
        "eventId",
        "title",
        "text",
        "iconName",
        "flags",
        "NotificationFlags",
        "componentName",
        "urls",
        "QList<QUrl>",
        "urgency",
        "Urgency",
        "autoDelete",
        "xdgActivationToken",
        "NotificationFlag",
        "CloseOnTimeout",
        "Persistent",
        "LoopSound",
        "SkipGrouping",
        "CloseWhenWindowActivated",
        "DefaultEvent",
        "DefaultUrgency",
        "LowUrgency",
        "NormalUrgency",
        "HighUrgency",
        "CriticalUrgency"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ignored'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eventIdChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconNameChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultActionChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionsChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'componentNameChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlsChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urgencyChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoDeleteChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xdgActivationTokenChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hintsChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendEvent'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setHint'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'hints'
        QtMocHelpers::SlotData<QVariantMap() const>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'setHints'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'eventId'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'flags'
        QtMocHelpers::PropertyData<NotificationFlags>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'componentName'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'urls'
        QtMocHelpers::PropertyData<QList<QUrl>>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'urgency'
        QtMocHelpers::PropertyData<enum Urgency>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'autoDelete'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'xdgActivationToken'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'hints'
        QtMocHelpers::PropertyData<QVariantMap>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'NotificationFlags'
        QtMocHelpers::EnumData<NotificationFlags>(31, 39, QMC::EnumIsFlag).add({
            {   40, NotificationFlag::CloseOnTimeout },
            {   41, NotificationFlag::Persistent },
            {   42, NotificationFlag::LoopSound },
            {   43, NotificationFlag::SkipGrouping },
            {   44, NotificationFlag::CloseWhenWindowActivated },
            {   45, NotificationFlag::DefaultEvent },
        }),
        // enum 'Urgency'
        QtMocHelpers::EnumData<enum Urgency>(36, 36, QMC::EnumFlags{}).add({
            {   46, Urgency::DefaultUrgency },
            {   47, Urgency::LowUrgency },
            {   48, Urgency::NormalUrgency },
            {   49, Urgency::HighUrgency },
            {   50, Urgency::CriticalUrgency },
        }),
    };
    return QtMocHelpers::metaObjectData<KNotification, qt_meta_tag_ZN13KNotificationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KNotification::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KNotificationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KNotificationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KNotificationE_t>.metaTypes,
    nullptr
} };

void KNotification::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KNotification *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->closed(); break;
        case 1: _t->ignored(); break;
        case 2: _t->eventIdChanged(); break;
        case 3: _t->titleChanged(); break;
        case 4: _t->textChanged(); break;
        case 5: _t->iconNameChanged(); break;
        case 6: _t->defaultActionChanged(); break;
        case 7: _t->actionsChanged(); break;
        case 8: _t->flagsChanged(); break;
        case 9: _t->componentNameChanged(); break;
        case 10: _t->urlsChanged(); break;
        case 11: _t->urgencyChanged(); break;
        case 12: _t->autoDeleteChanged(); break;
        case 13: _t->xdgActivationTokenChanged(); break;
        case 14: _t->hintsChanged(); break;
        case 15: _t->close(); break;
        case 16: _t->sendEvent(); break;
        case 17: _t->setHint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 18: { QVariantMap _r = _t->hints();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setHints((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::closed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::ignored, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::eventIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::titleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::textChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::iconNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::defaultActionChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::actionsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::flagsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::componentNameChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::urlsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::urgencyChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::autoDeleteChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::xdgActivationTokenChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotification::*)()>(_a, &KNotification::hintsChanged, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->eventId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 4: QtMocHelpers::assignFlags<NotificationFlags>(_v, _t->flags()); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->componentName(); break;
        case 6: *reinterpret_cast<QList<QUrl>*>(_v) = _t->urls(); break;
        case 7: *reinterpret_cast<enum Urgency*>(_v) = _t->urgency(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isAutoDelete(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->xdgActivationToken(); break;
        case 10: *reinterpret_cast<QVariantMap*>(_v) = _t->hints(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEventId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setIconName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setFlags(*reinterpret_cast<NotificationFlags*>(_v)); break;
        case 5: _t->setComponentName(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setUrls(*reinterpret_cast<QList<QUrl>*>(_v)); break;
        case 7: _t->setUrgency(*reinterpret_cast<enum Urgency*>(_v)); break;
        case 8: _t->setAutoDelete(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setHints(*reinterpret_cast<QVariantMap*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KNotification::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNotification::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KNotificationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNotification::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KNotification::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KNotification::ignored()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KNotification::eventIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KNotification::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KNotification::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KNotification::iconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KNotification::defaultActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KNotification::actionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KNotification::flagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KNotification::componentNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KNotification::urlsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KNotification::urgencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KNotification::autoDeleteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KNotification::xdgActivationTokenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KNotification::hintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
