/****************************************************************************
** Meta object code from reading C++ file 'knotificationqmlplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../knotifications-6.29.0/src/qml/knotificationqmlplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'knotificationqmlplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25NotificationActionForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationActionForeign::qt_create_metaobjectdata<qt_meta_tag_ZN25NotificationActionForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationActionForeign",
        "QML.Element",
        "NotificationAction",
        "QML.Foreign",
        "KNotificationAction"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<NotificationActionForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationActionForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25NotificationActionForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25NotificationActionForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25NotificationActionForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN30NotificationReplyActionForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationReplyActionForeign::qt_create_metaobjectdata<qt_meta_tag_ZN30NotificationReplyActionForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationReplyActionForeign",
        "QML.Element",
        "NotificationReplyAction",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "QML.Foreign",
        "KNotificationReplyAction"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<NotificationReplyActionForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationReplyActionForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30NotificationReplyActionForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30NotificationReplyActionForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30NotificationReplyActionForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19NotificationWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationWrapper",
        "QML.Element",
        "Notification",
        "actionsChanged",
        "defaultActionChanged",
        "replyAction",
        "KNotificationReplyAction*",
        "actions",
        "QQmlListProperty<KNotificationAction>",
        "defaultAction",
        "KNotificationAction*"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'replyAction'
        QtMocHelpers::PropertyData<KNotificationReplyAction*>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'actions'
        QtMocHelpers::PropertyData<QQmlListProperty<KNotificationAction>>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0x70000000 | 3),
        // property 'defaultAction'
        QtMocHelpers::PropertyData<KNotificationAction*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0x70000000 | 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NotificationWrapper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<KNotification::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationWrapperE_t>.metaTypes,
    nullptr
} };

void NotificationWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationWrapper *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNotificationAction* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNotificationReplyAction* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KNotificationReplyAction**>(_v) = _t->replyActionFactory(); break;
        case 1: *reinterpret_cast<QQmlListProperty<KNotificationAction>*>(_v) = _t->actionsProperty(); break;
        case 2: *reinterpret_cast<KNotificationAction**>(_v) = _t->defaultAction(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setDefaultActionQml(*reinterpret_cast<KNotificationAction**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationWrapperE_t>.strings))
        return static_cast<void*>(this);
    return KNotification::qt_metacast(_clname);
}

int NotificationWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KNotification::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
namespace CheckNotifySignalValidity_ZN19NotificationWrapperE {
template<typename T> using has_nullary_actionsChanged = decltype(std::declval<T>().actionsChanged());
template<typename T> using has_unary_actionsChanged = decltype(std::declval<T>().actionsChanged(std::declval<QQmlListProperty<KNotificationAction>>()));
static_assert(qxp::is_detected_v<has_nullary_actionsChanged, NotificationWrapper> || qxp::is_detected_v<has_unary_actionsChanged, NotificationWrapper>,
              "NOTIFY signal actionsChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_defaultActionChanged = decltype(std::declval<T>().defaultActionChanged());
template<typename T> using has_unary_defaultActionChanged = decltype(std::declval<T>().defaultActionChanged(std::declval<KNotificationAction*>()));
static_assert(qxp::is_detected_v<has_nullary_defaultActionChanged, NotificationWrapper> || qxp::is_detected_v<has_unary_defaultActionChanged, NotificationWrapper>,
              "NOTIFY signal defaultActionChanged does not exist in class (or is private in its parent)");
}
namespace {
struct qt_meta_tag_ZN29NotificationPermissionWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationPermissionWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN29NotificationPermissionWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationPermissionWrapper",
        "QML.Element",
        "NotificationPermission",
        "QML.Singleton",
        "true",
        "checkPermission",
        "",
        "requestPermission",
        "QJSValue",
        "callback"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'checkPermission'
        QtMocHelpers::MethodData<bool()>(5, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'requestPermission'
        QtMocHelpers::MethodData<void(const QJSValue &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<NotificationPermissionWrapper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationPermissionWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29NotificationPermissionWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29NotificationPermissionWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29NotificationPermissionWrapperE_t>.metaTypes,
    nullptr
} };

void NotificationPermissionWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationPermissionWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->checkPermission();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->requestPermission((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *NotificationPermissionWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationPermissionWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29NotificationPermissionWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NotificationPermissionWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
