/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<knotificationqmlplugin.h>)
#  include <knotificationqmlplugin.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_notification()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<KNotification *>().id();
    qmlRegisterEnum<KNotification::NotificationFlags>("KNotification::NotificationFlags");
    qmlRegisterEnum<KNotification::NotificationFlag>("KNotification::NotificationFlag");
    qmlRegisterEnum<KNotification::Urgency>("KNotification::Urgency");
    qmlRegisterTypesAndRevisions<NotificationActionForeign>("org.kde.notification", 1);
    qmlRegisterTypesAndRevisions<NotificationPermissionWrapper>("org.kde.notification", 1);
    qmlRegisterTypesAndRevisions<NotificationReplyActionForeign>("org.kde.notification", 1);
    qmlRegisterEnum<KNotificationReplyAction::FallbackBehavior>("KNotificationReplyAction::FallbackBehavior");
    qmlRegisterTypesAndRevisions<NotificationWrapper>("org.kde.notification", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.notification", 1, 0);
}

static const QQmlModuleRegistration orgkdenotificationRegistration("org.kde.notification", qml_register_types_org_kde_notification);
