/****************************************************************************
** Meta object code from reading C++ file 'knotificationreplyaction.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../knotifications-6.29.0/src/knotificationreplyaction.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'knotificationreplyaction.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24KNotificationReplyActionE_t {};
} // unnamed namespace

template <> constexpr inline auto KNotificationReplyAction::qt_create_metaobjectdata<qt_meta_tag_ZN24KNotificationReplyActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KNotificationReplyAction",
        "replied",
        "",
        "text",
        "activated",
        "labelChanged",
        "placeholderTextChanged",
        "submitButtonTextChanged",
        "submitButtonIconNameChanged",
        "fallbackBehaviorChanged",
        "label",
        "placeholderText",
        "submitButtonText",
        "submitButtonIconName",
        "fallbackBehavior",
        "FallbackBehavior",
        "HideAction",
        "UseRegularAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'replied'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'activated'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'placeholderTextChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'submitButtonTextChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'submitButtonIconNameChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackBehaviorChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'label'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'placeholderText'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'submitButtonText'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'submitButtonIconName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'fallbackBehavior'
        QtMocHelpers::PropertyData<enum FallbackBehavior>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FallbackBehavior'
        QtMocHelpers::EnumData<enum FallbackBehavior>(15, 15, QMC::EnumIsScoped).add({
            {   16, FallbackBehavior::HideAction },
            {   17, FallbackBehavior::UseRegularAction },
        }),
    };
    return QtMocHelpers::metaObjectData<KNotificationReplyAction, qt_meta_tag_ZN24KNotificationReplyActionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KNotificationReplyAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KNotificationReplyActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KNotificationReplyActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24KNotificationReplyActionE_t>.metaTypes,
    nullptr
} };

void KNotificationReplyAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KNotificationReplyAction *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->replied((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->activated(); break;
        case 2: _t->labelChanged(); break;
        case 3: _t->placeholderTextChanged(); break;
        case 4: _t->submitButtonTextChanged(); break;
        case 5: _t->submitButtonIconNameChanged(); break;
        case 6: _t->fallbackBehaviorChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KNotificationReplyAction::*)(const QString & )>(_a, &KNotificationReplyAction::replied, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotificationReplyAction::*)()>(_a, &KNotificationReplyAction::activated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotificationReplyAction::*)()>(_a, &KNotificationReplyAction::labelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotificationReplyAction::*)()>(_a, &KNotificationReplyAction::placeholderTextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotificationReplyAction::*)()>(_a, &KNotificationReplyAction::submitButtonTextChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotificationReplyAction::*)()>(_a, &KNotificationReplyAction::submitButtonIconNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNotificationReplyAction::*)()>(_a, &KNotificationReplyAction::fallbackBehaviorChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->placeholderText(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->submitButtonText(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->submitButtonIconName(); break;
        case 4: *reinterpret_cast<enum FallbackBehavior*>(_v) = _t->fallbackBehavior(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPlaceholderText(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setSubmitButtonText(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setSubmitButtonIconName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setFallbackBehavior(*reinterpret_cast<enum FallbackBehavior*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KNotificationReplyAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNotificationReplyAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KNotificationReplyActionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNotificationReplyAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KNotificationReplyAction::replied(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KNotificationReplyAction::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KNotificationReplyAction::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KNotificationReplyAction::placeholderTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KNotificationReplyAction::submitButtonTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KNotificationReplyAction::submitButtonIconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KNotificationReplyAction::fallbackBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
