

#ifndef SBK_KNOTIFICATIONS_PYTHON_H
#define SBK_KNOTIFICATIONS_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkmodule.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtgui_python.h>
#include <pyside6_qtcore_python.h>

// Bound library includes
#include <knotification.h>
#include <knotificationreplyaction.h>
#include <knotifyconfig.h>
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <qbytearrayview.h>
#include <qchar.h>
#include <QtCore/qlatin1stringview.h>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qvariant.h>

// Conversion Includes - Container Types
#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <array>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>


// Type indices
enum : int {
    SBK_KNotification_NotificationFlag_IDX                   = 1,
    SBK_QFlags_KNotification_NotificationFlag_IDX            = 9,
    SBK_KNotification_StandardEvent_IDX                      = 2,
    SBK_KNotification_Urgency_IDX                            = 3,
    SBK_KNotification_IDX                                    = 0,
    SBK_KNotificationAction_IDX                              = 4,
    SBK_KNotificationReplyAction_FallbackBehavior_IDX        = 7,
    SBK_KNotificationReplyAction_IDX                         = 6,
    SBK_KNotifyConfig_IDX                                    = 8,
    SBK_KNotifications_IDX_COUNT                             = 10,
};

// This variable stores all Python types exported by this module.
extern Shiboken::Module::TypeInitStruct *SbkKNotificationsTypeStructs;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkKNotificationsModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkKNotificationsTypeConverters;

// Converter indices
enum [[deprecated]] : int {
    SBK_KNOTIFICATIONS_QLIST_INT_IDX                         = 0, // QList<int>
    SBK_KNOTIFICATIONS_QLIST_KNOTIFICATIONACTIONPTR_IDX      = 1, // QList<KNotificationAction*>
    SBK_KNOTIFICATIONS_QMAP_QSTRING_QVARIANT_IDX             = 2, // QMap<QString,QVariant>
    SBK_KNOTIFICATIONS_QLIST_QURL_IDX                        = 3, // QList<QUrl>
    SBK_KNOTIFICATIONS_QLIST_QVARIANT_IDX                    = 4, // QList<QVariant>
    SBK_KNOTIFICATIONS_QLIST_QSTRING_IDX                     = 5, // QList<QString>
    SBK_KNOTIFICATIONS_CONVERTERS_IDX_COUNT                  = 6,
};

// Converter indices
enum : int {
    SBK_KNotifications_QList_int_IDX                         = 0, // QList<int>
    SBK_KNotifications_QList_KNotificationActionPTR_IDX      = 1, // QList<KNotificationAction*>
    SBK_KNotifications_QMap_QString_QVariant_IDX             = 2, // QMap<QString,QVariant>
    SBK_KNotifications_QList_QUrl_IDX                        = 3, // QList<QUrl>
    SBK_KNotifications_QList_QVariant_IDX                    = 4, // QList<QVariant>
    SBK_KNotifications_QList_QString_IDX                     = 5, // QList<QString>
    SBK_KNotifications_CONVERTERS_IDX_COUNT                  = 6,
};
// Macros for type check

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject *SbkType< ::KNotification::NotificationFlag >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotification_NotificationFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KNotification::NotificationFlag> >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_QFlags_KNotification_NotificationFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNotification::StandardEvent >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotification_StandardEvent_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNotification::Urgency >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotification_Urgency_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNotification >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotification_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNotificationAction >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotificationAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNotificationReplyAction::FallbackBehavior >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotificationReplyAction_FallbackBehavior_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNotificationReplyAction >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotificationReplyAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNotifyConfig >() { return Shiboken::Module::get(SbkKNotificationsTypeStructs[SBK_KNotifyConfig_IDX]); }

} // namespace Shiboken

QT_WARNING_POP
#endif // SBK_KNOTIFICATIONS_PYTHON_H

